@@ -119,6 +119,7 @@ ppc_error_hist <-
            ...,
            facet_args = list(),
            binwidth = NULL,
+           bins = NULL,
            breaks = NULL,
            freq = TRUE) {
 
@@ -133,8 +134,9 @@ ppc_error_hist <-
       geom_histogram(
         fill = get_color("l"),
         color = get_color("lh"),
-        size = 0.25,
+        linewidth = 0.25,
         binwidth = binwidth,
+        bins = bins,
         breaks = breaks
       ) +
       xlab(error_label()) +
@@ -162,6 +164,7 @@ ppc_error_hist_grouped <-
            ...,
            facet_args = list(),
            binwidth = NULL,
+           bins = NULL,
            breaks = NULL,
            freq = TRUE) {
 
@@ -307,26 +310,26 @@ ppc_error_binned <-
     point_fill <- get_color(ifelse(mixed_scheme, "m", "d"))
     point_color <- get_color(ifelse(mixed_scheme, "mh", "dh"))
 
-    ggplot(data, aes_(x = ~ ey_bar)) +
+    ggplot(data, aes(x = .data$ey_bar)) +
       hline_0(linetype = 2, color = "black") +
       geom_ribbon(
-        mapping = aes_(ymax = ~ se2, ymin = ~ -se2),
+        mapping = aes(ymax = .data$se2, ymin = -.data$se2),
         fill = get_color("l"),
         color = NA,
         alpha = alpha
       ) +
       geom_path(
-        mapping = aes_(y = ~ se2),
+        mapping = aes(y = .data$se2),
         color = get_color("l"),
-        size = size
+        linewidth = size
       ) +
       geom_path(
-        mapping = aes_(y = ~ -se2),
+        mapping = aes(y = -.data$se2),
         color = get_color("l"),
-        size = size
+        linewidth = size
       ) +
       geom_point(
-        mapping = aes_(y = ~ err_bar),
+        mapping = aes(y = .data$err_bar),
         shape = 21,
         fill = point_fill,
         color = point_color
@@ -396,10 +399,11 @@ error_hist_facets <-
 
     if (grouped) {
       facet_fun <- "facet_grid"
-      facet_args[["facets"]] <- rep_id ~ group
+      facet_args[["rows"]] <- vars(.data$rep_id)
+      facet_args[["cols"]] <- vars(.data$group)
     } else {
       facet_fun <- "facet_wrap"
-      facet_args[["facets"]] <- ~ rep_id
+      facet_args[["facets"]] <- vars(.data$rep_id)
     }
     facet_args[["scales"]] <- facet_args[["scales"]] %||% scales_default
 
