@@ -11,7 +11,7 @@ load(test_path("data-for-ordinal.rda"))
 # yrep_char <- posterior_predict(fit, draws = 50)
 # yrep_ord <- sapply(data.frame(yrep_char, stringsAsFactors = TRUE), as.integer)
 # group_ord <- datasets::esoph$agegp
-# save(y_ord, yrep_ord, group_ord, file = testthat::test_path("data-for-ordinal.rda"))
+# save(y_ord, yrep_ord, group_ord, file = testthat::test_path("data-for-ordinal.rda"), version = 2)
 
 
 # bar plots ---------------------------------------------------------------
@@ -68,15 +68,15 @@ test_that("ppc_bars_data includes all levels", {
   # yrep has more unique values than y
   d2 <- ppc_bars_data(y_ord2, yrep_ord)
   expect_equal(d2$x, 1:4)
-  expect_equal(d2$y_obs, c(NA, sum(tab[1:2]), tab[3:4]))
+  expect_equal(d2$y_obs, c(0, sum(tab[1:2]), tab[3:4]))
 
   # y has more unique values than yrep
   d3 <- ppc_bars_data(y_ord, yrep_ord2)
   expect_equal(d3$x, 1:4)
   expect_equal(d3$y_obs, tab)
-  expect_equivalent(d3$l[2], NA_real_)
-  expect_equivalent(d3$m[2], NA_real_)
-  expect_equivalent(d3$h[2], NA_real_)
+  expect_equivalent(d3$l[2], 0)
+  expect_equivalent(d3$m[2], 0)
+  expect_equivalent(d3$h[2], 0)
 })
 
 
@@ -104,6 +104,7 @@ test_that("ppc_rootogram errors if y/yrep not counts", {
 test_that("ppc_bars renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_bars(vdiff_y2, vdiff_yrep2)
   vdiffr::expect_doppelganger("ppc_bars (default)", p_base)
@@ -137,6 +138,7 @@ test_that("ppc_bars renders correctly", {
 test_that("ppc_bars_grouped renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_bars_grouped(vdiff_y2, vdiff_yrep2, vdiff_group2)
   vdiffr::expect_doppelganger("ppc_bars_grouped (default)", p_base)
@@ -158,6 +160,7 @@ test_that("ppc_bars_grouped renders correctly", {
 test_that("ppc_rootogram renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_rootogram(vdiff_y2, vdiff_yrep2)
   vdiffr::expect_doppelganger("ppc_rootogram (default)", p_base)
