@@ -24,20 +24,51 @@ test_that("ppc_stat throws errors if 'stat' wrong length", {
                "length(stat) == 1 is not TRUE", fixed = TRUE)
 })
 
+test_that("ppc_stat and ppc_stat_freqpoly message if stat='mean'", {
+  expect_message(
+    ppc_stat(y, yrep),
+    "'mean' is too weak to detect anything of interest"
+  )
+  expect_silent(
+    ppc_stat(y, yrep, stat = "mad")
+  )
+  expect_message(
+    ppc_stat_grouped(y, yrep, group),
+    "'mean' is too weak to detect anything of interest"
+  )
+  expect_silent(
+    ppc_stat_grouped(y, yrep, group, stat = "mad")
+  )
+  expect_message(
+    ppc_stat_freqpoly(y, yrep),
+    "'mean' is too weak to detect anything of interest"
+  )
+  expect_silent(
+    ppc_stat_freqpoly(y, yrep, group, stat = "mad")
+  )
+  expect_message(
+    ppc_stat_freqpoly_grouped(y, yrep, group),
+    "'mean' is too weak to detect anything of interest"
+  )
+  expect_silent(
+    ppc_stat_freqpoly_grouped(y, yrep, group, stat = "mad")
+  )
+})
+
 test_that("ppc_stat returns ggplot object", {
-  expect_gg(ppc_stat(y, yrep))
-  expect_gg(ppc_stat(y, yrep, stat = "sd"))
-  expect_gg(ppc_stat(y, yrep, stat = sd))
-  expect_gg(ppc_stat(y, yrep, stat = "q25"))
-  expect_gg(ppc_stat(y, yrep, stat = q25))
-  expect_gg(ppc_stat(y, yrep, stat = function(x) median(x)))
-  expect_gg(ppc_stat(y2, yrep2))
-  expect_gg(ppc_stat(y2, yrep2, stat = "prop0"))
+  expect_gg(ppc_stat(y, yrep, binwidth = 0.05))
+  expect_gg(ppc_stat(y, yrep, stat = "sd", binwidth = 0.05))
+  expect_gg(ppc_stat(y, yrep, stat = sd, binwidth = 0.05))
+  expect_gg(ppc_stat(y, yrep, stat = "q25", binwidth = 0.05))
+  expect_gg(ppc_stat(y, yrep, stat = q25, binwidth = 0.05))
+  expect_gg(ppc_stat(y, yrep, stat = function(x) median(x), binwidth = 0.05))
+  expect_gg(ppc_stat(y2, yrep2, binwidth = 0.05))
+  expect_gg(ppc_stat(y2, yrep2, stat = "prop0", binwidth = 0.05))
 
   # ppd versions
-  expect_gg(ppd_stat(yrep, stat = "q25"))
-  expect_gg(ppd_stat(yrep, stat = q25))
-  expect_gg(ppd_stat(yrep2, stat = "prop0"))
+  expect_gg(ppd_stat(yrep, stat = "q25", binwidth = 0.05))
+  expect_gg(ppd_stat(yrep, stat = q25, binwidth = 0.05))
+  expect_gg(ppd_stat(yrep2, stat = "prop0", binwidth = 0.05))
 })
 
 test_that("ppc_stat_2d returns ggplot object", {
@@ -59,17 +90,17 @@ test_that("ppc_stat_2d errors if more than 2 stats", {
 })
 
 test_that("ppc_stat_grouped returns ggplot object", {
-  expect_gg(ppc_stat_grouped(y, yrep, group))
-  expect_gg(ppc_stat_grouped(y, yrep, as.numeric(group), stat = function(z) var(z)))
-  expect_gg(ppc_stat_grouped(y, yrep, as.integer(group), stat = "sd"))
+  expect_gg(ppc_stat_grouped(y, yrep, group, binwidth = 0.05))
+  expect_gg(ppc_stat_grouped(y, yrep, as.numeric(group), stat = function(z) var(z), binwidth = 0.05))
+  expect_gg(ppc_stat_grouped(y, yrep, as.integer(group), stat = "sd", binwidth = 0.05))
 })
 
 test_that("ppc_stat_freqpoly_grouped returns ggplot object", {
-  expect_gg(ppc_stat_freqpoly_grouped(y, yrep, group, stat = "sd", freq = FALSE))
-  expect_gg(ppc_stat_freqpoly_grouped(y, yrep, group, stat = function(x) sd(x), freq = TRUE))
+  expect_gg(ppc_stat_freqpoly_grouped(y, yrep, group, stat = "sd", freq = FALSE, binwidth = 0.05))
+  expect_gg(ppc_stat_freqpoly_grouped(y, yrep, group, stat = function(x) sd(x), freq = TRUE, binwidth = 0.05))
 
   # ppd version
-  expect_gg(ppd_stat_freqpoly_grouped(yrep, group, stat = "sd", freq = FALSE))
+  expect_gg(ppd_stat_freqpoly_grouped(yrep, group, stat = "sd", freq = FALSE, binwidth = 0.05))
 })
 
 test_that("ppc_stat_data without the y values equal to ppd_stat_data", {
@@ -99,15 +130,16 @@ test_that("ppc_stat_data and ppd_stat_data throw correct errors", {
 test_that("ppc_stat renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
-  p_base <- ppc_stat(vdiff_y, vdiff_yrep) + yaxis_text()
+  p_base <- ppc_stat(vdiff_y, vdiff_yrep, binwidth = 0.05) + yaxis_text()
   vdiffr::expect_doppelganger("ppc_stat (default)", p_base)
 
   p_custom <- ppc_stat(
     y = vdiff_y,
     yrep = vdiff_yrep,
     stat = "mad",
-    binwidth = .05,
+    binwidth = 0.05,
     freq = FALSE
   ) + yaxis_text()
   vdiffr::expect_doppelganger(
@@ -115,13 +147,13 @@ test_that("ppc_stat renders correctly", {
     fig = p_custom)
 
   # ppd versions
-  p_base <- ppd_stat(vdiff_yrep) + yaxis_text()
+  p_base <- ppd_stat(vdiff_yrep, binwidth = 0.05) + yaxis_text()
   vdiffr::expect_doppelganger("ppd_stat (default)", p_base)
 
   p_custom <- ppd_stat(
     ypred = vdiff_yrep,
     stat = "mad",
-    binwidth = .05,
+    binwidth = 0.05,
     freq = FALSE
   ) + yaxis_text()
   vdiffr::expect_doppelganger(
@@ -132,6 +164,7 @@ test_that("ppc_stat renders correctly", {
 test_that("ppc_stat_2d renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
   p_base <- ppc_stat_2d(vdiff_y, vdiff_yrep)
   vdiffr::expect_doppelganger("ppc_stat_2d (default)", p_base)
@@ -165,8 +198,9 @@ test_that("ppc_stat_2d renders correctly", {
 test_that("ppc_stat_grouped renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
-  p_base <- ppc_stat_grouped(vdiff_y, vdiff_yrep, vdiff_group)
+  p_base <- ppc_stat_grouped(vdiff_y, vdiff_yrep, vdiff_group, binwidth = 0.05)
   vdiffr::expect_doppelganger("ppc_stat_grouped (default)", p_base)
 
   p_custom <- ppc_stat_grouped(
@@ -175,14 +209,14 @@ test_that("ppc_stat_grouped renders correctly", {
     group = vdiff_group,
     stat = stats::var,
     facet_args = list(scales = "fixed", ncol = 1),
-    binwidth = .25
+    binwidth = 0.25
   )
   vdiffr::expect_doppelganger(
     title = "ppc_stat_grouped (stat, facet_args, binwidth)",
     fig = p_custom)
 
   # ppd versions
-  p_base <- ppd_stat_grouped(vdiff_yrep, vdiff_group)
+  p_base <- ppd_stat_grouped(vdiff_yrep, vdiff_group, binwidth = 0.05)
   vdiffr::expect_doppelganger("ppd_stat_grouped (default)", p_base)
 
   p_custom <- ppd_stat_grouped(
@@ -190,7 +224,7 @@ test_that("ppc_stat_grouped renders correctly", {
     group = vdiff_group,
     stat = stats::var,
     facet_args = list(scales = "fixed", ncol = 1),
-    binwidth = .25
+    binwidth = 0.25
   )
   vdiffr::expect_doppelganger(
     title = "ppd_stat_grouped (stat, facet_args, binwidth)",
@@ -200,8 +234,9 @@ test_that("ppc_stat_grouped renders correctly", {
 test_that("ppc_stat_freqpoly_grouped renders correctly", {
   testthat::skip_on_cran()
   testthat::skip_if_not_installed("vdiffr")
+  skip_on_r_oldrel()
 
-  p_base <- ppc_stat_freqpoly_grouped(vdiff_y, vdiff_yrep, vdiff_group)
+  p_base <- ppc_stat_freqpoly_grouped(vdiff_y, vdiff_yrep, vdiff_group, binwidth = 0.05)
   vdiffr::expect_doppelganger("ppc_stat_freqpoly_grouped (default)", p_base)
 
   p_custom <- ppc_stat_freqpoly_grouped(
@@ -210,14 +245,14 @@ test_that("ppc_stat_freqpoly_grouped renders correctly", {
     group = vdiff_group,
     stat = "sum",
     facet_args = list(scales = "fixed", ncol = 1),
-    binwidth = .5
+    binwidth = 0.5
   )
   vdiffr::expect_doppelganger(
-    title = "ppc_stat_freqpoly_grouped (stat, facet_args, binwidth)",
+    title = "ppc_stat_freqpoly_grouped (stat, facets, bw)",
     fig = p_custom)
 
   # ppd versions
-  p_base <- ppd_stat_freqpoly_grouped(vdiff_yrep, vdiff_group)
+  p_base <- ppd_stat_freqpoly_grouped(vdiff_yrep, vdiff_group, binwidth = 0.05)
   vdiffr::expect_doppelganger("ppd_stat_freqpoly_grouped (default)", p_base)
 
   p_custom <- ppd_stat_freqpoly_grouped(
@@ -225,9 +260,9 @@ test_that("ppc_stat_freqpoly_grouped renders correctly", {
     group = vdiff_group,
     stat = "sum",
     facet_args = list(scales = "fixed", ncol = 1),
-    binwidth = .5
+    binwidth = 0.5
   )
   vdiffr::expect_doppelganger(
-    title = "ppd_stat_freqpoly_grouped (stat, facet_args, binwidth)",
+    title = "ppd_stat_freqpoly_grouped (stat, facets, bw)",
     fig = p_custom)
 })
